@@ -125,11 +125,13 @@ def next_version(c, registry=None, image=None):
     print(_get_next_version(c, registry, image))
 
 
-def docker_exec(c, command, container=None, pty=True, envs={}):
+def docker_exec(c, command, container=None, pty=True, envs={}, workdir=None):
     container = container or c.config.container
     run_command = "docker exec "
     if pty:
         run_command += "-it "
+    if workdir:
+        run_command += f"-w {workdir}"
     for env_var, env_value in envs.items():
         run_command += f"--env {env_var}={env_value} "
 
@@ -181,7 +183,8 @@ def shell(c):
 
 @task
 def pyshell(c):
-    docker_exec(c, "python")
+    pyshell = c.config.get("container_pyshell", "ipython")
+    docker_exec(c, pyshell)
 
 
 @task
